==> alg-alg-2.22.29-sources.jar: cn/com/duiba/nezha/alg/alg/vo/advert/AdBidParamsDo.java <==
package cn.com.duiba.nezha.alg.alg.vo.advert;

import lombok.Data;

@Data
public class AdBidParamsDo {


    Long fee;// 最终出价

    Long aFee;//ocpx 广告 转化目标出价（配置的）

    Long appAFee;//ocpx 广告 媒体 转化目标出价（******   新增 !!!! *******）

    Long deepFee;//深度目标成本（2020.11.12）


    Integer chargeType; //是否ocpc，1：cpc、2：ocpc

    Integer cvrType;//ocpx 转化目标类型，目前支持：0、2、3（2020.09.10）

    Integer deepCvrType;//ocpx 深度转化目标类型，目前支持：8（2020.09.10）



    /**
     * 维稳参数
     */
    Long factorType;//维稳类型，1 配置  2 广告位

    Double factor;// 维稳因子=pcFactor*fcFactor

    Double pcFactor;// 预估值校准因子

    Double fcFactor;// 跑量因子

    /**
     * 维稳重置标记
     */

    Integer resetType;//1:出价调节  2：管理后台调节


    /**
     * 底价控制参数
     */

    Long reserveFee;//底价
    Boolean reservePriceWhite;//底价生效白名单，白名单内不触发

    Boolean isGiveUp; //本次出价是否放弃


    Long giveUpFee;// 底价放弃阈值-出价

    Double giveUpRatio;// 底价放弃阈值-概率


    /**
     * 出价保护-出价下降
     */
    Boolean coldProject;// 出价保护- 是否冷启动保护

    Long coldProjectFeeDiff;// 出价保护-冷启动出价下降



    Boolean secondPriceProject;// 出价保护，是否二阶保护

//    Double secondPriceProjectFactor;// 出价保护，二阶因子

    Double cFactor;// 维稳调价因子（在成本修正后）


    /**
     * 出价试探-出价增长
     */
    Boolean explore;// 出价试探-是否试探

    Long exploreFeeDiff;// 出价试探-出价增长

    Double exploreFactor;


    /**
     * 双出价流量标识
     */


    Integer deepControlType;// 双出价模式： null：无  1-优化后端成本（适合转化延迟情况）   2-保后端成本  3-保消耗+优化后端成本

    Double deepControlFactor;// 双出价 调价因子

    Integer deepDelayType;// 双出价后端延迟类型： null：无  1：10分钟内   2：10分钟以上

    /**
     * 自动定向流量标识
     */

    Boolean isAutoTarget;// 是否自动定向流量


    /**
     * 跑量模式流量表识
     */
    Integer bidControlType;// 竞价策略，1：常规；2：跑量模式（2020.11.12）


    Integer abTestId;// 竞价策略，AB分流 测试Id（1：默认组、2：实验组...）

    /**
     * 双出价白名单是否全部生效
     */

    Boolean deepAllEffect;

    /**
     * 控制策略
     */
    Integer releaseTarget;  //1-稳定投放，2-抢量优先(中)， 3-抢量优先(高)， 4-人工定向， 5-成本优先


    /**
     * 双出价 参数
     *
     */

    Integer statDcvrDimType; //1-广告位、2-配置
    Double slotStatDcvr; //配置+广告位，离线统计转化率
    Double pkStatDcvr; //配置，离线统计转化率
    Double preDcvr; //预估转化率

}

==> alg-alg-2.23.78-sources.jar: cn/com/duiba/nezha/alg/alg/vo/advert/AdBidParamsDo.java <==
package cn.com.duiba.nezha.alg.alg.vo.advert;

import lombok.Data;

@Data
public class AdBidParamsDo {


    Long fee;// 最终出价

    Long aFee;//ocpx 广告 转化目标出价（配置的）

    Long appAFee;//ocpx 广告 媒体 转化目标出价（******   新增 !!!! *******）

    Long deepFee;//深度目标成本（2020.11.12）


    Integer chargeType; //是否ocpc，1：cpc、2：ocpc

    Integer cvrType;//ocpx 转化目标类型，目前支持：0、2、3（2020.09.10）

    Integer deepCvrType;//ocpx 深度转化目标类型，目前支持：8（2020.09.10）

    Long slotId;//广告位id
    Long packageId;//配置id


    /**
     * 维稳参数
     */
    Long factorType;//维稳类型，1 配置  2 广告位

    Double factor;// 维稳因子=pcFactor*fcFactor

    Double pcFactor;// 预估值校准因子

    Double fcFactor;// 跑量因子

    /**
     * 维稳重置标记
     */

    Integer resetType;//1:出价调节  2：管理后台调节


    /**
     * 底价控制参数
     */

    Long reserveFee;//底价
    Boolean reservePriceWhite;//底价生效白名单，白名单内不触发

    Boolean isGiveUp; //本次出价是否放弃


    Long giveUpFee;// 底价放弃阈值-出价

    Double giveUpRatio;// 底价放弃阈值-概率


    /**
     * 出价保护-出价下降
     */
    Boolean coldProject;// 出价保护- 是否冷启动保护

    Long coldProjectFeeDiff;// 出价保护-冷启动出价下降


    Boolean secondPriceProject;// 出价保护，是否二阶保护

//    Double secondPriceProjectFactor;// 出价保护，二阶因子

    Double cFactor;// 维稳调价因子（在成本修正后）


    /**
     * 出价试探-出价增长
     */
    Boolean explore;// 出价试探-是否试探

    Long exploreFeeDiff;// 出价试探-出价增长

    Double exploreFactor;


    Long defaultFee;// 冷启动参考出价

    /**
     * 双出价流量标识
     */


    Integer deepControlType;// 双出价模式： null：无 0-白名单测试  1-保后端成本   2-保消耗  3-优化后端成本（适合转化延迟情况）

    Double deepControlFactor;// 双出价 调价因子

    Integer deepDelayType;// 双出价后端延迟类型： null：无  1：10分钟内   2：10分钟以上

    /**
     * 自动定向流量标识
     */

    Boolean isAutoTarget;// 是否自动定向流量


    /**
     * 是否跑量测试白名单
     */
    Integer bidControlType;// 是否跑量测试白名单， null：无  1：无   2：是


    /**
     * 是否新o测试白名单
     * null：无  1：无   2：是
     */
    Integer isNewOTest;// 是否新o测试白名单（null：无  1：无  2：是）2021.3.1

    /**
     * 新o分流表识
     */
    Integer newOAbTestId;// 新o测试AB分流 测试Id（1：默认组、2：实验组...）2021.3.1

    /**
     * 是否冷启动测试白名单
     * null：无  1：无   2：是
     */
    Integer isColdTest;// 是否冷启动测试白名单（null：无  1：无  2：是）2021.3.1

    /**
     * 冷启动分流表识
     */
    Integer coldAbTestId;// 冷启动AB分流 测试Id（1：默认组、2：实验组...） 2021.3.1


    /**
     * 双出价分流表识
     */
    Integer abTestId;// 竞价策略，AB分流 测试Id（1：默认组、2：实验组...）

    /**
     * 跑量分流表识
     */
    Integer fastAbTestId;// 跑量AB分流 测试Id（1：默认组、2：实验组...） 2021.2.22


    /**
     * 双出价白名单是否全部生效
     */

    Boolean deepAllEffect;

    /**
     * 控制策略
     */
    Integer releaseTarget;  //1-稳定投放，2-抢量优先(中)， 3-抢量优先(高)， 4-人工定向， 5-成本优先


    /**
     * 双出价 参数
     */

    Integer statDcvrDimType; //1-广告位、2-配置
    Double slotStatDcvr; //配置+广告位，离线统计转化率
    Double pkStatDcvr; //配置，离线统计转化率
    Double preDcvr; //预估转化率
    Double deepConfWeight;//预估置信权重
    Double statDeepFactor; //统计深度因子
    Double preDeepFactor; //预估深度因子

    /**
     * 是否限流媒体 1:被限流过滤
     */

    Integer appLimitReleaseMark;

    String updateTime;//参数更新时间

    /**
     * 是否开启提价保量模式（0=不开启，1=开启）
     */
    Integer priceRiseMark;

    /**
     * 提价保量因子
     */
    Double prFactor;// 提价保量因子

    /**
     * 原始出价
     */
    Long originalFee;//原始出价

}
